==> zio-aws-mturk_2.13-5.17.152.1-sources.jar: zio/aws/mturk/model/ListHiTsResponse.scala <==
package zio.aws.mturk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mturk.model.primitives.{Integer, PaginationToken}
import scala.jdk.CollectionConverters._
final case class ListHiTsResponse(
    nextToken: Option[PaginationToken] = None,
    numResults: Option[Integer] = None,
    hiTs: Option[Iterable[zio.aws.mturk.model.HIT]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mturk.model.ListHiTsResponse = {
    import ListHiTsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mturk.model.ListHiTsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(numResults.map(value => value: java.lang.Integer))(
        _.numResults
      )
      .optionallyWith(
        hiTs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.hiTs)
      .build()
  }
  def asReadOnly: zio.aws.mturk.model.ListHiTsResponse.ReadOnly =
    zio.aws.mturk.model.ListHiTsResponse.wrap(buildAwsValue())
}
object ListHiTsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mturk.model.ListHiTsResponse =
      zio.aws.mturk.model.ListHiTsResponse(
        nextToken.map(value => value),
        numResults.map(value => value),
        hiTs.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[PaginationToken]
    def numResults: Option[Integer]
    def hiTs: Option[List[zio.aws.mturk.model.HIT.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getNumResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("numResults", numResults)
    def getHiTs: ZIO[Any, AwsError, List[zio.aws.mturk.model.HIT.ReadOnly]] =
      AwsError.unwrapOptionField("hiTs", hiTs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ) extends zio.aws.mturk.model.ListHiTsResponse.ReadOnly {
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.mturk.model.primitives.PaginationToken(value))
    override val numResults: Option[Integer] =
      scala.Option(impl.numResults()).map(value => value: Integer)
    override val hiTs: Option[List[zio.aws.mturk.model.HIT.ReadOnly]] = scala
      .Option(impl.hiTs())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.mturk.model.HIT.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ): zio.aws.mturk.model.ListHiTsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mturk_2.13-5.17.169.1-sources.jar: zio/aws/mturk/model/ListHiTsResponse.scala <==
package zio.aws.mturk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mturk.model.primitives.{Integer, PaginationToken}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListHiTsResponse(
    nextToken: Optional[PaginationToken] = Optional.Absent,
    numResults: Optional[Integer] = Optional.Absent,
    hiTs: Optional[Iterable[zio.aws.mturk.model.HIT]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mturk.model.ListHiTsResponse = {
    import ListHiTsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mturk.model.ListHiTsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(numResults.map(value => value: java.lang.Integer))(
        _.numResults
      )
      .optionallyWith(
        hiTs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.hiTs)
      .build()
  }
  def asReadOnly: zio.aws.mturk.model.ListHiTsResponse.ReadOnly =
    zio.aws.mturk.model.ListHiTsResponse.wrap(buildAwsValue())
}
object ListHiTsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mturk.model.ListHiTsResponse =
      zio.aws.mturk.model.ListHiTsResponse(
        nextToken.map(value => value),
        numResults.map(value => value),
        hiTs.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Optional[PaginationToken]
    def numResults: Optional[Integer]
    def hiTs: Optional[List[zio.aws.mturk.model.HIT.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getNumResults: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("numResults", numResults)
    def getHiTs: ZIO[Any, AwsError, List[zio.aws.mturk.model.HIT.ReadOnly]] =
      AwsError.unwrapOptionField("hiTs", hiTs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ) extends zio.aws.mturk.model.ListHiTsResponse.ReadOnly {
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.mturk.model.primitives.PaginationToken(value))
    override val numResults: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.numResults())
      .map(value => value: Integer)
    override val hiTs: Optional[List[zio.aws.mturk.model.HIT.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.hiTs())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mturk.model.HIT.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mturk.model.ListHiTsResponse
  ): zio.aws.mturk.model.ListHiTsResponse.ReadOnly = new Wrapper(impl)
}
